@@ -24,8 +24,10 @@
  *
  */
 
-enum { MP_version=1000,
-       MP_ed_automatic_contig_editing,
+enum { MP_ed_mira_automatic_contig_editing=1000,
+       MP_ed_kmer_singlets,
+       MP_ed_homopolymer_overcalls,
+       MP_ed_edit_automatic_contig_editing,
        MP_ed_strict,
        MP_ed_confirmation_threshold,
 
@@ -57,7 +59,6 @@ enum { MP_version=1000,
        MP_as_uniform_read_distribution,
        MP_as_urd_startinpass,
        MP_as_urd_cutoffmultiplier,
-       MP_as_keep_long_repeats_separated,
        MP_as_cleanup_tmp_files,
        MP_as_savesimplesingletsinproject,
        MP_as_savetaggedsingletsinproject,
@@ -137,7 +138,7 @@ enum { MP_version=1000,
        MP_as_clip_ssahamerge_strictfrontclip,
        MP_as_clip_ssahamerge_strictendclip,
        MP_as_clip_polyat,
-       MP_as_clip_polyat_keeppolysignal,
+       MP_as_clip_polyat_keeppolystretch,
        MP_as_clip_polyat_len,
        MP_as_clip_polyat_maxerrors,
        MP_as_clip_polyat_maxgap,
@@ -162,9 +163,13 @@ enum { MP_version=1000,
        MP_as_backbone_rail_fromstrain,
        MP_as_startbackboneusage_inpass,
        MP_as_backbone_alsobuildnewcontigs,
+       MP_as_backbone_trimoverhangingreads,
+       MP_as_backbone_bootstrapnewbackbone,
 
        MP_sk_numthreads=5000,
        MP_sk_basesperhash,
+       MP_sk_bph_increasestep,
+       MP_sk_bph_coveragethreshold,
        MP_sk_hashsavestepping,
        MP_sk_percentrequired,
        MP_sk_maxhitsperread,
@@ -185,6 +190,8 @@ enum { MP_version=1000,
        MP_hs_nastyrepeatcoverage,
        MP_hs_repeatlevel_in_infofile,
        MP_hs_applydigitalnormalisation,
+       MP_hs_million_hashes_per_buffer,
+       MP_hs_rare_kmer_early_kill,
 
        MP_al_bip=5500,
        MP_al_bmax,
@@ -247,19 +254,26 @@ enum { MP_version=1000,
        MP_con_gap_override_ratio,
 
        MP_mi_extendedlog=7700,
+       MP_mi_iknowwhatido,
        MP_mi_as_largecontigsize,
        MP_mi_as_largecontigsize4stats,
        MP_mi_extra_flag1,
        MP_mi_extra_flag2,
+       MP_mi_extra_flag3,
 
-       MP_nw_stoponnfs=7800,
-       MP_nw_stop_maxreadnamelength,
+       MP_nw_check_nfs=7800,
+       MP_nw_check_templateproblems,
+       MP_nw_check_duplicatereadnames,
+       MP_nw_check_maxreadnamelength,
+       MP_nw_check_multipassmapping,
+       MP_nw_check_mrnlvalue,
+       MP_nw_check_coverage,
+       MP_nw_check_covvalue,
 
        MP_fn_cafin=7900,
        MP_fn_cafout,
 
-       MP_dir_cwd=8000,
-       MP_dir_tmp,
+       MP_dir_tmp=8000,
        MP_dir_tmp_redirectedto,
 
        MP_quickmode_borg=8200,
@@ -274,9 +288,12 @@ enum { MP_version=1000,
        MP_quickmode_noclipping_text,
        MP_quickmode_noclipping_solexa,
        MP_quickmode_noclipping_solid,
-       MP_quickmode_highlyrepetitive,
+       MP_quickmode_hirep_something,
+       MP_quickmode_hirep_good,
+       MP_quickmode_hirep_best,
        MP_quickmode_highqualitydata,
        MP_quickmode_lowqualitydata,
+       MP_quickmode_highlyrepetitive,
 
        MP_jobdefstart=8300,
        MP_jobdef_draft,
